aboutsummaryrefslogtreecommitdiff
path: root/odb/cache-traits.hxx
diff options
context:
space:
mode:
authorBoris Kolpackov <boris@codesynthesis.com>2010-12-09 12:00:24 +0200
committerBoris Kolpackov <boris@codesynthesis.com>2010-12-09 12:00:24 +0200
commitd74e6724c0d313167eb3c8762892fa6a81024f00 (patch)
tree5759aec99380847c4f54b8099676169a6e21c873 /odb/cache-traits.hxx
parentb7135a4be85c27e209acf15a709f789af51baf8f (diff)
Cosmetic change (rename naked pointer to raw pointer)
Diffstat (limited to 'odb/cache-traits.hxx')
-rw-r--r--odb/cache-traits.hxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/odb/cache-traits.hxx b/odb/cache-traits.hxx
index a475d35..ea8f504 100644
--- a/odb/cache-traits.hxx
+++ b/odb/cache-traits.hxx
@@ -110,7 +110,7 @@ namespace odb
};
// Caching traits for objects passed by reference. Only if the object
// pointer kind is naked do we add the object to the session.
//
template <typename T,
pointer_kind =
@@ -144,7 +144,7 @@ namespace odb
};
template <typename T>
- struct reference_cache_traits<T, pk_naked>
+ struct reference_cache_traits<T, pk_raw>
{
typedef T element_type;
typedef typename object_traits<element_type>::pointer_type pointer_type;
@@ -110,7 +110,7 @@ namespace odb
};
// Caching traits for objects passed by reference. Only if the object
- // pointer kind is naked do we add the object to the session.
+ // pointer kind is raw do we add the object to the session.
//
template <typename T,